==> box64_0.3.4+dfsg.orig.tar.xz: box64-0.3.4/src/wrapped32/wrappedfreetype_private.h <==
#if !(defined(GO) && defined(GOM) && defined(GO2) && defined(DATA))
#error meh!
#endif

// FT_Bitmap is struct uuipWCCp

GOM(FT_Activate_Size, iFEp)
//GO(FT_Add_Default_Modules, vFp)
//GO(FT_Add_Module, 
//GO(FT_Angle_Diff, lFll)
//GO(FT_Atan2, lFll)
//GO(FT_Attach_File, iFpp)
//GO(FT_Attach_Stream, iFpp)
GO(FT_Bitmap_Convert, iFpruuipWCCp_buuipWCCp_i)
//GO(FT_Bitmap_Copy, iFppp)
GO(FT_Bitmap_Done, iFpruuipWCCp_)
//GO(FT_Bitmap_Embolden, iFppll)
GO(FT_Bitmap_Init, vFbuuipWCCp_)
GO(FT_Bitmap_New, vFbuuipWCCp_)
//GO(FT_CeilFix, 
//GO(FT_ClassicKern_Free, 
//GO(FT_ClassicKern_Validate, 
GO(FT_Cos, lFl)
GO(FT_DivFix, lFll)
GOM(FT_Done_Face, iFEp)
GO(FT_Done_FreeType, iFp)
GOM(FT_Done_Glyph, vFEp)
//GO(FT_Done_Library, iFp)
//GO(FT_Done_MM_Var, iFpp)
GOM(FT_Done_Size, iFEp)
//GO(FT_Face_CheckTrueTypePatents, 
//GO(FT_Face_GetCharsOfVariant, 
//GO(FT_Face_GetCharVariantIndex, uFpuu)
//GO(FT_Face_GetCharVariantIsDefault, 
//GO(FT_Face_GetVariantSelectors, 
//GO(FT_Face_GetVariantsOfChar, 
//GO(FT_Face_Properties, iFpup)
//GO(FT_Face_SetUnpatentedHinting, 
GO(FT_FloorFix, lFl)
//GO(FT_Get_Advance, iFpiup)
//GO(FT_Get_Advances, iFpuuip)
//GO(FT_Get_BDF_Charset_ID, 
GOM(FT_Get_BDF_Property, iFEppp)
GOM(FT_Get_Char_Index, uFEpL)
//GO(FT_Get_Charmap_Index, iFp)
//GO(FT_Get_Color_Glyph_Layer, iFpupp)
//GO(FT_Get_Color_Glyph_Paint, iFpuip)
//GO(FT_Get_Color_Glyph_ClipBox, iFpup)
//GO(FT_Get_Colorline_Stops, iFppp)
//GO(FT_Get_CID_From_Glyph_Index, 
//GO(FT_Get_CID_Is_Internally_CID_Keyed, 
//GO(FT_Get_CID_Registry_Ordering_Supplement, 
//GO(FT_Get_CMap_Format, 
//GO(FT_Get_CMap_Language_ID, 
GOM(FT_Get_First_Char, LFEpp)
//GO(FT_Get_Font_Format, pFp)
//GO(FT_Get_FSType_Flags, WFp)
//GO(FT_Get_Gasp, 
GOM(FT_Get_Glyph, iFEpp)
GOM(FT_Get_Glyph_Name, iFEpupu)
GOM(FT_Get_Kerning, iFEpuuup)
//GO(FT_Get_MM_Blend_Coordinates, 
//GO(FT_Get_MM_Var, iFpp)
//GO(FT_Get_Module, pFpp)
//GO(FT_Get_Multi_Master, 
//GO(FT_Get_Name_Index, uFpp)
GOM(FT_Get_Next_Char, LFEpLp)
//GO(FT_Get_Paint, iFppip)    // FT_OpaquePaint is a struct with "pi"
//GO(FT_Get_Paint_Layers, iFppp)
//GO(FT_Get_PFR_Advance, 
//GO(FT_Get_PFR_Kerning, 
//GO(FT_Get_PFR_Metrics, 
GOM(FT_Get_Postscript_Name, pFEp)
GOM(FT_Get_PS_Font_Info, iFEpp)
//GO(FT_Get_PS_Font_Private, 
//GO(FT_Get_PS_Font_Value, 
//GO(FT_Get_Renderer, pFpu)
//GO(FT_Get_Sfnt_LangTag, 
GOM(FT_Get_Sfnt_Name, iFEpip)
GOM(FT_Get_Sfnt_Name_Count, uFEp)
GOM(FT_Get_Sfnt_Table, pFEpi)
//GO(FT_Get_SubGlyph_Info, iFpuppppp)
//GO(FT_Get_Track_Kerning, iFplip)
//GO(FT_Get_Transform, vFppp)
GO(FT_Get_TrueType_Engine_Type, uFp)
//GO(FT_Get_Var_Blend_Coordinates, iFpup)
//GO(FT_Get_Var_Design_Coordinates, 
GOM(FT_Get_WinFNT_Header, iFEpp)
GOM(FT_Get_X11_Font_Format, pFEp)
GOM(FT_Glyph_Copy, iFEpBp_)
GOM(FT_Glyph_Get_CBox, vFEpuBLLLL_)
//GO(FT_GlyphSlot_Embolden, vFp)
//GO(FT_GlyphSlot_Oblique, vFp)
//GO(FT_GlyphSlot_Own_Bitmap, iFp)
//GO(FT_Glyph_Stroke, iFppC)
//GO(FT_Glyph_StrokeBorder, iFppCC)
//GO(FT_Glyph_To_Bitmap, iFpupC)
GOM(FT_Glyph_Transform, iFEprllll_rll_)
//GO(FT_Gzip_Uncompress, 
GOM(FT_Has_PS_Glyph_Names, iFEp)
GO(FT_Init_FreeType, iFBp_)
GO(FT_Library_SetLcdFilter, iFpu)
//GO(FT_Library_SetLcdFilterWeights, iFpp)
GO(FT_Library_Version, vFpppp)
//GO(FT_List_Add, 
//GO(FT_List_Finalize, 
//GO(FT_List_Find, pFpp)
//GO(FT_List_Insert, 
//GO(FT_List_Iterate, 
//GO(FT_List_Remove, 
//GO(FT_List_Up, vFpp)
GOM(FT_Load_Char, iFEpLi)
GOM(FT_Load_Glyph, iFEpui)
GOM(FT_Load_Sfnt_Table, iFEpLlpp)
//GO(FT_Matrix_Invert, iFp)
GOM(FT_Matrix_Multiply, vFEpp)
GO(FT_MulDiv, lFlll)
GO(FT_MulFix, lFll)
GOM(FT_New_Face, iFEpplp)
//GOM(FT_New_Library, iFEpp)
GOM(FT_New_Memory_Face, iFEppllp)
GOM(FT_New_Size, iFEpp)
GOM(FT_Open_Face, iFEpplp)
//GO(FT_OpenType_Free, vFpp)
//GO(FT_OpenType_Validate, iFpuppppp)
//GO(FT_Outline_Check, iFp)
GOM(FT_Outline_Copy, iFEpp)
GOM(FT_Outline_Decompose, iFEppp)
GOM(FT_Outline_Done, iFEpp)
//GO(FT_Outline_Done_Internal, 
GOM(FT_Outline_Embolden, iFEpl)
GOM(FT_Outline_EmboldenXY, iFEpll)
//GO(FT_Outline_Get_BBox, iFpp)
GOM(FT_Outline_Get_Bitmap, iFEppp)
GOM(FT_Outline_Get_CBox, vFEpp)
//GO(FT_Outline_GetInsideBorder, 
//GO(FT_Outline_Get_Orientation, uFp)
//GO(FT_Outline_GetOutsideBorder, uFp)
GOM(FT_Outline_New, iFEpuip)
//GO(FT_Outline_New_Internal, 
//GO(FT_Outline_Render, iFppp)
//GO(FT_Outline_Reverse, vFp)
GOM(FT_Outline_Transform, vFEpp)
GOM(FT_Outline_Translate, vFEpll)
//GO(FT_Palette_Select, iFpWp)
//GO(FT_Property_Get, iFpppp)
GO(FT_Property_Set, iFpppp)
//GO(FT_Reference_Face, iFp)
//GO(FT_Reference_Library, 
//GO(FT_Remove_Module, iFpp)
GOM(FT_Render_Glyph, iFEpu)
GOM(FT_Request_Size, iFEpp)
//GO(FT_RoundFix, 
GOM(FT_Select_Charmap, iFEpi)
GOM(FT_Select_Size, iFEpi)
GOM(FT_Set_Charmap, iFEpp)
GOM(FT_Set_Char_Size, iFEplluu)
//GO(FT_Set_Debug_Hook, 
//GO(FT_Set_Default_Properties, vFp)
//GO(FT_Set_MM_Blend_Coordinates, 
//GO(FT_Set_MM_Design_Coordinates, iFpup)
GOM(FT_Set_Pixel_Sizes, iFEpuu)
//GO(FT_Set_Renderer, iFppup)
GOM(FT_Set_Transform, vFEppp)
//GO(FT_Set_Var_Blend_Coordinates, 
//GO(FT_Set_Var_Design_Coordinates, iFpup)
//GO(FT_Sfnt_Table_Info, iFpupp)
//GO(FT_Sin, lFl)
//GO(FT_Stream_OpenBzip2, 
//GO(FT_Stream_OpenGzip, 
//GO(FT_Stream_OpenLZW, 
//GO(FT_Stroker_BeginSubPath, iFppC)
//GO(FT_Stroker_ConicTo, iFppp)
//GO(FT_Stroker_CubicTo, iFpppp)
//GO(FT_Stroker_Done, vFp)
//GO(FT_Stroker_EndSubPath, iFp)
//GO(FT_Stroker_Export, vFpp)
//GO(FT_Stroker_ExportBorder, vFpup)
//GO(FT_Stroker_GetBorderCounts, iFpupp)
//GO(FT_Stroker_GetCounts, iFppp)
//GO(FT_Stroker_LineTo, iFpp)
//GO(FT_Stroker_New, iFpp)
//GO(FT_Stroker_ParseOutline, iFppC)
//GO(FT_Stroker_Rewind, vFp)
//GO(FT_Stroker_Set, vFpluul)
//GO(FT_Tan, lFl)
//GO(FT_TrueTypeGX_Free, 
//GO(FT_TrueTypeGX_Validate, 
//GO(FT_Vector_From_Polar, vFpll)
GO(FT_Vector_Length, lFrll_)
//GO(FT_Vector_Polarize, vFppp)
//GO(FT_Vector_Rotate, vFpl)
GO(FT_Vector_Transform, vFbll_rllll_)
GO(FT_Vector_Unit, vFBll_l)

//GO(FTC_CMapCache_Lookup, uFppiu)
//GO(FTC_CMapCache_New, iFpp)
//GO(FTC_ImageCache_Lookup, iFppupp)
//GO(FTC_ImageCache_LookupScaler, iFppLupp)
//GO(FTC_ImageCache_New, iFpp)
//GO(FTC_Manager_Done, vFp)
//GO(FTC_Manager_LookupFace, iFppp)
//GO(FTC_Manager_LookupSize, iFppp)
//GOM(FTC_Manager_New, iFEpuuLppp)
//GO(FTC_Manager_RemoveFaceID, vFpp)
//GO(FTC_Manager_Reset, vFp)
//GO(FTC_Node_Unref, vFpp)
//GO(FTC_SBitCache_Lookup, iFppupp)
//GO(FTC_SBitCache_LookupScaler, iFppLupp)
//GO(FTC_SBitCache_New, iFpp)

//GO(TT_New_Context, 
//GO(TT_RunIns,

==> box64_0.3.8+dfsg.orig.tar.xz: box64-0.3.8/src/wrapped32/wrappedfreetype_private.h <==
#if !(defined(GO) && defined(GOM) && defined(GO2) && defined(DATA))
#error meh!
#endif

// FT_Bitmap is struct uuipWCCp

GOM(FT_Activate_Size, iFEp)
//GO(FT_Add_Default_Modules, vFp)
//GO(FT_Add_Module, 
//GO(FT_Angle_Diff, lFll)
//GO(FT_Atan2, lFll)
//GO(FT_Attach_File, iFpp)
//GO(FT_Attach_Stream, iFpp)
GO(FT_Bitmap_Convert, iFpruuipWCCp_buuipWCCp_i)
//GO(FT_Bitmap_Copy, iFppp)
GO(FT_Bitmap_Done, iFpruuipWCCp_)
GO(FT_Bitmap_Embolden, iFpruuipWCCp_ll)
GO(FT_Bitmap_Init, vFbuuipWCCp_)
GO(FT_Bitmap_New, vFbuuipWCCp_)
//GO(FT_CeilFix, 
//GO(FT_ClassicKern_Free, 
//GO(FT_ClassicKern_Validate, 
GO(FT_Cos, lFl)
GO(FT_DivFix, lFll)
GOM(FT_Done_Face, iFEp)
GO(FT_Done_FreeType, iFp)
GOM(FT_Done_Glyph, vFEp)
//GO(FT_Done_Library, iFp)
GOM(FT_Done_MM_Var, iFEpp)
GOM(FT_Done_Size, iFEp)
//GO(FT_Face_CheckTrueTypePatents, 
//GO(FT_Face_GetCharsOfVariant, 
GOM(FT_Face_GetCharVariantIndex, uFEpLL)
//GO(FT_Face_GetCharVariantIsDefault, 
//GO(FT_Face_GetVariantSelectors, 
//GO(FT_Face_GetVariantsOfChar, 
//GO(FT_Face_Properties, iFpup)
//GO(FT_Face_SetUnpatentedHinting, 
GO(FT_FloorFix, lFl)
GOM(FT_Get_Advance, iFEpiup)
GOM(FT_Get_Advances, iFEpuuip)
//GO(FT_Get_BDF_Charset_ID, 
GOM(FT_Get_BDF_Property, iFEppp)
GOM(FT_Get_Char_Index, uFEpL)
//GO(FT_Get_Charmap_Index, iFp)
//GO(FT_Get_Color_Glyph_Layer, iFpupp)
//GO(FT_Get_Color_Glyph_Paint, iFpuip)
//GO(FT_Get_Color_Glyph_ClipBox, iFpup)
//GO(FT_Get_Colorline_Stops, iFppp)
//GO(FT_Get_CID_From_Glyph_Index, 
//GO(FT_Get_CID_Is_Internally_CID_Keyed, 
//GO(FT_Get_CID_Registry_Ordering_Supplement, 
//GO(FT_Get_CMap_Format, 
//GO(FT_Get_CMap_Language_ID, 
GOM(FT_Get_First_Char, LFEpp)
//GO(FT_Get_Font_Format, pFp)
GOM(FT_Get_FSType_Flags, WFEp)
//GO(FT_Get_Gasp, 
GOM(FT_Get_Glyph, iFEpp)
GOM(FT_Get_Glyph_Name, iFEpupu)
GOM(FT_Get_Kerning, iFEpuuup)
//GO(FT_Get_MM_Blend_Coordinates, 
GOM(FT_Get_MM_Var, iFEpp)
//GO(FT_Get_Module, pFpp)
//GO(FT_Get_Multi_Master, 
GOM(FT_Get_Name_Index, uFEpp)
GOM(FT_Get_Next_Char, LFEpLp)
//GO(FT_Get_Paint, iFppip)    // FT_OpaquePaint is a struct with "pi"
//GO(FT_Get_Paint_Layers, iFppp)
//GO(FT_Get_PFR_Advance, 
//GO(FT_Get_PFR_Kerning, 
//GO(FT_Get_PFR_Metrics, 
GOM(FT_Get_Postscript_Name, pFEp)
GOM(FT_Get_PS_Font_Info, iFEpp)
//GO(FT_Get_PS_Font_Private, 
//GO(FT_Get_PS_Font_Value, 
//GO(FT_Get_Renderer, pFpu)
//GO(FT_Get_Sfnt_LangTag, 
GOM(FT_Get_Sfnt_Name, iFEpip)
GOM(FT_Get_Sfnt_Name_Count, uFEp)
GOM(FT_Get_Sfnt_Table, pFEpi)
//GO(FT_Get_SubGlyph_Info, iFpuppppp)
//GO(FT_Get_Track_Kerning, iFplip)
//GO(FT_Get_Transform, vFppp)
GO(FT_Get_TrueType_Engine_Type, uFp)
GOM(FT_Get_Var_Blend_Coordinates, iFEpup)
//GO(FT_Get_Var_Design_Coordinates, 
GOM(FT_Get_WinFNT_Header, iFEpp)
GOM(FT_Get_X11_Font_Format, pFEp)
GOM(FT_Glyph_Copy, iFEpBp_)
GOM(FT_Glyph_Get_CBox, vFEpuBLLLL_)
//GO(FT_GlyphSlot_Embolden, vFp)
//GO(FT_GlyphSlot_Oblique, vFp)
GOM(FT_GlyphSlot_Own_Bitmap, iFEp)
//GO(FT_Glyph_Stroke, iFppC)
//GO(FT_Glyph_StrokeBorder, iFppCC)
//GO(FT_Glyph_To_Bitmap, iFpupC)
GOM(FT_Glyph_Transform, iFEprllll_rll_)
//GO(FT_Gzip_Uncompress, 
GOM(FT_Has_PS_Glyph_Names, iFEp)
GO(FT_Init_FreeType, iFBp_)
GO(FT_Library_SetLcdFilter, iFpu)
//GO(FT_Library_SetLcdFilterWeights, iFpp)
GO(FT_Library_Version, vFpppp)
//GO(FT_List_Add, 
//GO(FT_List_Finalize, 
//GO(FT_List_Find, pFpp)
//GO(FT_List_Insert, 
//GO(FT_List_Iterate, 
//GO(FT_List_Remove, 
//GO(FT_List_Up, vFpp)
GOM(FT_Load_Char, iFEpLi)
GOM(FT_Load_Glyph, iFEpui)
GOM(FT_Load_Sfnt_Table, iFEpLlpp)
//GO(FT_Matrix_Invert, iFp)
GOM(FT_Matrix_Multiply, vFEpp)
GO(FT_MulDiv, lFlll)
GO(FT_MulFix, lFll)
GOM(FT_New_Face, iFEpplp)
//GOM(FT_New_Library, iFEpp)
GOM(FT_New_Memory_Face, iFEppllp)
GOM(FT_New_Size, iFEpp)
GOM(FT_Open_Face, iFEpplp)
//GO(FT_OpenType_Free, vFpp)
//GO(FT_OpenType_Validate, iFpuppppp)
//GO(FT_Outline_Check, iFp)
GOM(FT_Outline_Copy, iFEpp)
GOM(FT_Outline_Decompose, iFEppp)
GOM(FT_Outline_Done, iFEpp)
//GO(FT_Outline_Done_Internal, 
GOM(FT_Outline_Embolden, iFEpl)
GOM(FT_Outline_EmboldenXY, iFEpll)
//GO(FT_Outline_Get_BBox, iFpp)
GOM(FT_Outline_Get_Bitmap, iFEppp)
GOM(FT_Outline_Get_CBox, vFEpp)
//GO(FT_Outline_GetInsideBorder, 
//GO(FT_Outline_Get_Orientation, uFp)
//GO(FT_Outline_GetOutsideBorder, uFp)
GOM(FT_Outline_New, iFEpuip)
//GO(FT_Outline_New_Internal, 
//GO(FT_Outline_Render, iFppp)
//GO(FT_Outline_Reverse, vFp)
GOM(FT_Outline_Transform, vFEpp)
GOM(FT_Outline_Translate, vFEpll)
//GO(FT_Palette_Select, iFpWp)
//GO(FT_Property_Get, iFpppp)
GO(FT_Property_Set, iFpppp)
GOM(FT_Reference_Face, iFEp)
//GO(FT_Reference_Library, 
//GO(FT_Remove_Module, iFpp)
GOM(FT_Render_Glyph, iFEpu)
GOM(FT_Request_Size, iFEpp)
//GO(FT_RoundFix, 
GOM(FT_Select_Charmap, iFEpi)
GOM(FT_Select_Size, iFEpi)
GOM(FT_Set_Charmap, iFEpp)
GOM(FT_Set_Char_Size, iFEplluu)
//GO(FT_Set_Debug_Hook, 
//GO(FT_Set_Default_Properties, vFp)
//GO(FT_Set_MM_Blend_Coordinates, 
//GO(FT_Set_MM_Design_Coordinates, iFpup)
GOM(FT_Set_Pixel_Sizes, iFEpuu)
//GO(FT_Set_Renderer, iFppup)
GOM(FT_Set_Transform, vFEppp)
GOM(FT_Set_Var_Blend_Coordinates, iFEpup)
//GO(FT_Set_Var_Design_Coordinates, iFpup)
//GO(FT_Sfnt_Table_Info, iFpupp)
//GO(FT_Sin, lFl)
//GO(FT_Stream_OpenBzip2, 
//GO(FT_Stream_OpenGzip, 
//GO(FT_Stream_OpenLZW, 
//GO(FT_Stroker_BeginSubPath, iFppC)
//GO(FT_Stroker_ConicTo, iFppp)
//GO(FT_Stroker_CubicTo, iFpppp)
//GO(FT_Stroker_Done, vFp)
//GO(FT_Stroker_EndSubPath, iFp)
//GO(FT_Stroker_Export, vFpp)
//GO(FT_Stroker_ExportBorder, vFpup)
//GO(FT_Stroker_GetBorderCounts, iFpupp)
//GO(FT_Stroker_GetCounts, iFppp)
//GO(FT_Stroker_LineTo, iFpp)
//GO(FT_Stroker_New, iFpp)
//GO(FT_Stroker_ParseOutline, iFppC)
//GO(FT_Stroker_Rewind, vFp)
//GO(FT_Stroker_Set, vFpluul)
//GO(FT_Tan, lFl)
//GO(FT_TrueTypeGX_Free, 
//GO(FT_TrueTypeGX_Validate, 
//GO(FT_Vector_From_Polar, vFpll)
GO(FT_Vector_Length, lFrll_)
//GO(FT_Vector_Polarize, vFppp)
//GO(FT_Vector_Rotate, vFpl)
GO(FT_Vector_Transform, vFbll_rllll_)
GO(FT_Vector_Unit, vFBll_l)

//GO(FTC_CMapCache_Lookup, uFppiu)
//GO(FTC_CMapCache_New, iFpp)
//GO(FTC_ImageCache_Lookup, iFppupp)
//GO(FTC_ImageCache_LookupScaler, iFppLupp)
//GO(FTC_ImageCache_New, iFpp)
//GO(FTC_Manager_Done, vFp)
//GO(FTC_Manager_LookupFace, iFppp)
//GO(FTC_Manager_LookupSize, iFppp)
//GOM(FTC_Manager_New, iFEpuuLppp)
//GO(FTC_Manager_RemoveFaceID, vFpp)
//GO(FTC_Manager_Reset, vFp)
//GO(FTC_Node_Unref, vFpp)
//GO(FTC_SBitCache_Lookup, iFppupp)
//GO(FTC_SBitCache_LookupScaler, iFppLupp)
//GO(FTC_SBitCache_New, iFpp)

//GO(TT_New_Context, 
//GO(TT_RunIns,
